#################################################
# load libraries, read in data                  #
#################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(ggplot2)    

#move data folder to desktop
setwd("~/Desktop/Data")

total = read.csv("forward_flow_data_long.csv")
total_avg = read.csv("forward_flow_data_avg.csv")

#################################################
# Model                                         #
#################################################

library(effects)
model <- lmer(score_z ~ cond*idea_number +(idea_number|Group.Number) + (1|study), data=total)

#Run the interaction 
predictions <- effect('cond*idea_number', model,
                      xlevels=list(cond_main = c("In-Person","Virtual"),
                                   idea_number = c(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50)),
                      type="scheffe", confidence.level=.95, typical=mean)
#Put data in data frame 
predictions <- as.data.frame(predictions)
predictions$cond <- factor(predictions$cond)

#Create a factor of the Work Ethic variable used in the interaction 
predictions$idea_number <- factor(predictions$idea_number,
                                  levels=c(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50),
                                  labels=c("1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28","29","30","31","32","33","34","35","36","37","38","39","40","41","42","43","44","45","46","47","48","49","50"))

predictions$idea_number = as.numeric(predictions$idea_number)
        
#################################################
# GRAPH                                         #
#################################################

point_cols = c("#045a8d","#99ccff")

large_points <- function(data, params, size) {
  # Multiply by some number
  data$size <- data$size * 3
  draw_key_point(data = data, params = params, size = size)
}

total_graph = total %>% filter(idea_number>1) %>% filter(score_z < 3.0)
mean(total_graph$score_z)
sd(total_graph$score_z)


ggplot(total_graph, aes(x = idea_number, y =score_z, group=cond)) + 
  geom_point(position = "jitter", alpha=0.6, aes(shape = cond, color = cond)) +
  scale_shape_manual(name="Legend 1", values=c(19, 4)) +
  scale_color_manual(name="Legend 1", values=c("skyblue2", "navyblue")) +
  #geom_ribbon(aes(ymin=lower, ymax=upper), alpha=0.3) + 
  theme_classic() +
  geom_line(data = predictions, aes(y=fit, linetype=cond), size = 1) + 
  ylab("Standardized Foward Flow")+
  xlab("Idea Position")+
  scale_x_continuous(limits = c(2, 30),
                     breaks = c(2, 10, 20, 30),
                     labels = c("2nd", "10th","20th","30th")) +
  theme(axis.title.x = element_text(face="bold", size=12), 
        axis.title.y = element_text(face="bold", size=12),
        axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 10),
        legend.text=element_text(size=18),
        legend.title = element_blank(), 
        plot.title = element_text( face = "bold", size = (15),hjust = 0.5))+ 
  guides(color = guide_legend(override.aes = list(size=2.8)))         



