#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(effsize)
library(MASS)
library(car)

#move data folder to desktop
setwd("~/Desktop/Data")


d1 = read.csv("study1_data.csv")
d2 = read.csv("study2_data.csv")

d3 = read.csv("field_scored_data.csv")
d4 = read.csv("field_generation_data.csv")

#########################################################
# merge two datasets                                    #
#########################################################

d1 = d1 %>% dplyr::select(Group.Number, cond, idea_number, creative_count, diff, p_select_creative, top_creative, avg_creative) %>%
  mutate(study = "1")
d2 = d2 %>% dplyr::select(Group.Number, cond, idea_number, creative_count, diff, p_select_creative, top_creative, avg_creative) %>%
  mutate(study = "2")

d = rbind(d1, d2)

#########################################################
# Poisson vs. Neg Binomial: Lab Study                   #
#########################################################

#poisson
possion1 = glm(idea_number ~ cond + study, family="poisson",data = d)
possion2 = glm(creative_count ~ cond + study, family="poisson",data = d)

#negative binomial
negbin1 = glm.nb(idea_number ~ cond + study, data = d)
negbin2 = glm.nb(creative_count ~ cond + study, data = d)

library(AER)
dispersiontest(possion1,trafo=1)
dispersiontest(possion2,trafo=1)

AIC(possion1, negbin1)
AIC(possion2, negbin2)

library(pscl)
vuong(possion1, negbin1, digits = 4)
vuong(possion2, negbin2, digits = 4)

#########################################################
# Alternative Models Generation: Lab study              #
#########################################################

#quasipoisson
summary(glm(idea_number ~ cond + study, family="quasipoisson",data = d))
summary(glm(creative_count ~ cond + study, family="quasipoisson",data = d))

#adjusted
library(AER)
pois_mod = glm(creative_count ~ cond + study, family="poisson", data=d)
dispersiontest(pois_mod)
summary(pois_mod,dispersion = 1.469508)

pois_mod = glm(idea_number ~ cond + study, family="poisson", data=d)
dispersiontest(pois_mod)
summary(pois_mod,dispersion = 2.801458)

#linear
summary(lm(idea_number ~ cond + study, data = d))
summary(lm(creative_count ~ cond + study, data = d))

#permutation
library(coin)
d$cond = as.factor(d$cond)
d$study = as.factor(d$study)

coin::independence_test(idea_number ~ cond, data = d)

coin::independence_test(creative_count ~ cond, data = d)


#########################################################
# Poisson vs. Neg Binomial: field                       #
#########################################################

#poisson
possion1 = glmer(idea_number ~ cond + country + (1|session), family="poisson", data = d4)
possion2 = glmer(creative_count ~ cond + country + (1|session), family="poisson", data = d3)

possion1a = glm(idea_number ~ cond + country, family="poisson", data = d4)
possion2a = glm(creative_count ~ cond + country, family="poisson", data = d3)

#negative binomial
negbin1 = glmer.nb(idea_number ~ cond + country + (1|session), data = d4)
negbin2 = glmer.nb(creative_count ~ cond+ country + (1|session), data = d3)

negbin1a = glm.nb(idea_number ~ cond + country, data = d4)
negbin2a = glm.nb(creative_count ~ cond + country, data = d3)

library(AER)
dispersiontest(possion1a,trafo=1)
dispersiontest(possion2a,trafo=1)

AIC(possion1, negbin1)
AIC(possion2, negbin2)

library(pscl)
vuong(possion1a, negbin1a, digits = 4)
vuong(possion2a, negbin2a, digits = 4)


#quasipoisson
summary(glm(idea_number ~ cond + country, family="quasipoisson",data = d4))
summary(glm(creative_count ~ cond, family="quasipoisson",data = d3))

#adjusted
library(AER)
pois_mod = glm(creative_count ~ cond, family="poisson", data=d3)
dispersiontest(pois_mod)
summary(pois_mod,dispersion = 2.21)

pois_mod = glm(idea_number ~ cond, family="poisson", data=d4)
dispersiontest(pois_mod)
summary(pois_mod,dispersion = 3.90)

#linear
summary(lmer(idea_number ~ cond + country + (1|session), data = d4))
summary(lmer(creative_count ~ cond + country + (1|session), data = d3))

#permutation
library(coin)
d3$cond = as.factor(d3$cond)
d4$cond = as.factor(d4$cond)
coin::independence_test(idea_number ~ cond, data = d4)

coin::independence_test(creative_count ~ cond, data = d3)


#######################################################
# Selection, Lab & field Studies, test for normality  #
#######################################################

hist(d$diff)
hist(d$p_select_creative)
hist(d3$diff)
hist(d3$p_select_score)

shapiro.test(d$diff)
shapiro.test(d$p_select_creative)
shapiro.test(d$avg_creative)
shapiro.test(d$var_creative)

shapiro.test(d3$diff)
shapiro.test(d3$p_select_score)
shapiro.test(d3$avg_creative)
shapiro.test(d3$var_creative)

#########################################################
# Lab and field: test for homogeneity of variance       #
#########################################################

leveneTest(diff ~ cond, data = d)
leveneTest(p_select_creative ~ cond, data = d)
leveneTest(avg_creative ~ cond, data = d)

leveneTest(diff ~ cond, data = d3)
leveneTest(p_select_score ~ cond, data = d3)
leveneTest(avg_creative ~ cond, data = d3)

### non-parametric tests ###
kruskal.test(diff ~ cond, data = d3)
kruskal.test(p_select_creative ~ cond, data = d)
kruskal.test(avg_creative ~ cond, data = d)
