#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d_byp = read.csv("study1_survey_by_participant.csv")
d = read.csv("study1_survey_by_group.csv")
t = read.csv("study2_transcript_coordination_data.csv")

#########################################################
# means by condition                                    #
#########################################################

############ Subjective Coordination Issues #############

#block2 = "How often did you feel like you were talking over each other?"

d_byp %>%
  group_by(cond) %>%
  summarise(mean = mean(block2, na.rm=T),
            sd = sd(block2, na.rm=T))

############ Transcriber Coordination Issues #############

t %>% gather(variable, score, back_and_forth, crosstalk) %>%
  group_by(variable, cond) %>%
  summarise(mean = mean(score),
            sd = sd(score))

#########################################################
# Regressions                                            #
#########################################################

##### Does condition affect subjective convo coord ######

summary(lmer(block2 ~ cond + (1|Group.Number), data = d_byp))

#### Does subjective convo coord affect creativity  #####

summary(glm.nb(creative_count ~ block2, data = d))

############### Controlling for convo coord #############

summary(glm.nb(creative_count ~ block2 + cond, data = d))

## Does condition affect transciber-rated convo coord ##

summary(lm(crosstalk ~ cond, data = t))
summary(lm(back_and_forth ~ cond, data = t))

## Does transciber-rated convo coord affect creativity ##

summary(glm.nb(creative_count ~ back_and_forth, data = t))
summary(glm.nb(creative_count ~ crosstalk, data = t))

summary(glm.nb(creative_count ~ back_and_forth + crosstalk, data = t))

############### Controlling for convo coord #############

summary(glm.nb(creative_count ~ cond + back_and_forth, data = t))
summary(glm.nb(creative_count ~ cond + crosstalk, data = t))

summary(glm.nb(creative_count ~ cond + crosstalk + back_and_forth, data = t))

#######################################################
# effect sizes                                        #
#######################################################

#2 people didn't take the survey
d.noNA = d_byp %>% filter(!is.na(block2))
cohen.d(d.noNA$block2, d.noNA$cond)

cohen.d(t$back_and_forth, t$cond)
cohen.d(t$crosstalk, t$cond)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(crosstalk ~ cond, data = t)
leveneTest(back_and_forth ~ cond, data = t)
leveneTest(block2 ~ cond, data = d1_byp)

#########################################################
# test for normality                                    #
#########################################################

hist(t$crosstalk)
hist(t$back_and_forth)
hist(d1_byp$block2)

shapiro.test(t$crosstalk)
shapiro.test(t$back_and_forth)
shapiro.test(d1_byp$block2)

### non-parametric tests ###

kruskal.test(crosstalk ~ cond, data = t)
kruskal.test(back_and_forth ~ cond, data = t)
kruskal.test(block2 ~ cond, data = d1)

