#!/usr/bin/env python
"""perform auto correct for input word"""

import os
from spellchecker import SpellChecker
import pandas as pd
import numpy as np


class corrector():
    """
    corrector class
    """

    def __init__(self):
        """
        create corrector instance
        """
        self.correction_dict = {}
        self.spell = SpellChecker()


    def assign_config(self, CONFIG):
        """
        assign value to the config field
        """
        self.CONFIG = CONFIG
        if(CONFIG["use_correction_file"]==1):
            self.load_correction_file()

    def load_correction_file(self):
        """
        load self-defined correction file as dictionary
        """
        df = pd.read_csv(self.CONFIG["correction_path"])
        for idx, row in df.iterrows():
            self.correction_dict[row[0]] = row[1]
            if row[1] == np.nan:
                self.correction_dict[row[0]] = ""
            elif row[1] == "":
                self.correction_dict[row[0]] = ""




    def auto_correct(self, sentence, LSA_DICT):
        """
        auto correction of the sentence
        """

        bag_of_words = sentence.lower().split()
        word_list = []

        for single_word in bag_of_words:
            if single_word not in LSA_DICT.keys():
                # make correction
                new_word = self.spell.correction(single_word)
                word_list.append(new_word)

                # mark correction in correction mapping
                self.record_correction(single_word, new_word)
            else:
                word_list.append(single_word)

        return " ".join(word_list)

    def auto_correct_by_file(self, sentence, LSA_DICT):
        """
        auto correction of the sentence
        """

        bag_of_words = sentence.lower().split()
        word_list = []

        for single_word in bag_of_words:
            if single_word not in LSA_DICT.keys():
                try:
                    new_word = self.correction_dict[single_word]
                    if type(new_word) == type(""):
                        word_list.append(new_word)
                except Exception as e:
                    word_list.append("")
                    print(e)
            else:
                word_list.append(single_word)

        return " ".join(word_list)


    def record_correction(self, old_word, new_word):
        '''
        store the old_word to new_word mapping in a dictionary
        this dictionary is output to a correction file at the end
        '''
        if new_word != old_word:
            self.correction_dict[old_word] = new_word
        else:
            self.correction_dict[old_word] = ""

    def output_correction_dict(self):
        '''
        generate a csv file, containing all the replacement we used
        '''

        correction_list = []
        for key, value in self.correction_dict.items():
            correction_list.append([key, value])

        correction_df = pd.DataFrame(correction_list)
        correction_df.columns = ["old", "new"]
        correction_df.to_csv(self.CONFIG["correction_path"], index=False)
