#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(effsize)
library(car)
library(MASS)
library(lmerTest)

#move data folder to desktop
setwd("~/Desktop/Data")

d_byp = read.csv("eyegaze_data_by_participant.csv")
d = read.csv("eyegaze_data_by_group.csv")

#########################################################
# means by condition                                    #
#########################################################

d_byp %>% gather(key, value, contains("time"), - total_time) %>%
  group_by(key,cond) %>%
  summarise(mean = mean(value),
            sd = sd(value))

#########################################################
# regressions                                           #
#########################################################

summary(lmer(task_time ~ cond + (1|Group.Number), data= d_byp))
summary(lmer(partner_time ~ cond + (1|Group.Number), data= d_byp))
summary(lmer(room_time ~ cond + (1|Group.Number), data= d_byp))

#########################################################
# mediation                                             #
#########################################################

Model.M <- lm(room_time ~ cond, data=d)
Model.Y <- glm.nb(creative_count ~ cond + room_time, d)
med.model <- mediation::mediate(Model.M, Model.Y, treat= 'cond', mediator = 'room_time', boot = T, sims = 10000)  
summary(med.model) 

summary(Model.Y)
summary(Model.M)

summary(glm.nb(creative_count ~ room_time, data = d)) 
summary(glm.nb(creative_count ~ cond, data = d)) 
#the total effect is different here compared to the main data set because of missing video data
#e.g., video too dark, video did not save. See manuscript for more info.

#######################################################
# Effect Sizes                                        #
#######################################################

cohen.d(d_byp$task_time, d_byp$cond)
cohen.d(d_byp$partner_time, d_byp$cond)
cohen.d(d_byp$room_time, d_byp$cond)

#######################################################
# test for normality                                  #
#######################################################

hist(d$task_time)
hist(d$partner_time)
hist(d$room_time)

shapiro.test(d$task_time)
shapiro.test(d$partner_time)
shapiro.test(d$room_time)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(task_time ~ cond, data = d)
leveneTest(partner_time ~ cond, data = d)
leveneTest(room_time ~ cond, data = d)

### non-parametric tests ###
kruskal.test(partner_time ~ cond, data = d)
kruskal.test(room_time ~ cond, data = d)