#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d = read.csv("facial_mimicry_data.csv")

#########################################################
# test for normality                                    #
#########################################################

hist(d$facial_sim)
shapiro.test(d$facial_sim)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(facial_sim ~ cond, data = d)

#########################################################
# means by condition                                    #
#########################################################

d %>%
  group_by(cond) %>%
  summarise(mean = mean(facial_sim, na.rm=T),
            sd = sd(facial_sim, na.rm=T))

#########################################################
# regressions                                           #
#########################################################

######### Does condition affect facial mimcry ###########

summary(lm(facial_sim ~ cond, data = d))
cohen.d(d$facial_sim, d$cond)

### non-parametric tests ###
kruskal.test(d$facial_sim ~ d$cond)

######### Does facial mimicry affect creativity #########

summary(glm.nb(creative_count ~ facial_sim, data = d))
summary(glm.nb(creative_count ~ cond + facial_sim, data = d))
