#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d1_survey = read.csv("study1_survey_by_participant.csv")
d2_survey = read.csv("study2_survey_by_participant.csv")

d1_all = read.csv("study1_survey_by_group.csv")
d2_all = read.csv("study2_survey_by_group.csv")

###########################################################
# Self-censorship and perceptions of criticism in Study 1 #
###########################################################

####### means by condition #######   
d1_survey %>% group_by(cond) %>%
  gather(key, value, self_censor, crit_mean) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

####### regressions ####### 

#does condition affect these?
summary(lmer(crit_mean ~ cond + (1|Group.Number), data = d1_survey))
summary(lmer(self_censor ~ cond + (1|Group.Number), data = d1_survey))

#do these predict creativity?
summary(glm.nb(creative_count ~ crit_mean, data = d1_all))
summary(glm.nb(creative_count ~ self_censor, data = d1_all))

#controlling for these
summary(glm.nb(creative_count ~ self_censor + cond, data = d1_all))
summary(glm.nb(creative_count ~ crit_mean + cond, data = d1_all))

summary(glm.nb(creative_count ~ crit_mean + self_censor + cond, data = d1_all))

###########################################################
# Perceptions of warmth and self-presentation in Study 2  #
###########################################################

####### means by condition #######   
d2_survey %>% group_by(cond) %>%
  gather(key, value, warm_mean, pub_mean) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

####### regressions ####### 

#does condition affect these?
summary(lmer(warm_mean ~ cond + (1|Group.Number), data = d2_survey))
summary(lmer(pub_mean ~ cond + (1|Group.Number), data = d2_survey))

#do these predict creativity?
summary(glm.nb(creative_count ~ warm_mean,  data = d2_all))
summary(glm.nb(creative_count ~ pub_mean, data = d2_all))

#controlling for these
summary(glm.nb(creative_count ~ warm_mean + cond, data = d2_all))
summary(glm.nb(creative_count ~ pub_mean + cond, data = d2_all))

summary(glm.nb(creative_count ~ pub_mean + warm_mean + cond, data = d2_all))

#########################################################
# test for normality                                    #
#########################################################

hist(d1_survey$crit_mean)
hist(d1_survey$self_censor)
hist(d2_survey$warm_mean)
hist(d2_survey$pub_mean)

shapiro.test(d1_survey$crit_mean)
shapiro.test(d1_survey$self_censor)
shapiro.test(d2_survey$warm_mean)
shapiro.test(d2_survey$pub_mean)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(d1_survey$crit_mean ~ d1_survey$cond)
leveneTest(d1_survey$self_censor ~ d1_survey$cond)
leveneTest(d2_survey$warm_mean ~ d2_survey$cond)
leveneTest(d2_survey$pub_mean ~ d2_survey$cond)

### non-parametric tests ###
kruskal.test(d1_all$crit_mean ~ d1_all$cond)
kruskal.test(d1_all$self_censor ~ d1_all$cond)
kruskal.test(d2_all$warm_mean ~ d2_all$cond)
kruskal.test(d2_all$pub_mean ~ d2_all$cond)

###########################################################
# Effect Sizes                                            #
###########################################################

d.noNA = d1_survey %>% filter(!is.na(crit_mean))
cohen.d(d.noNA$crit_mean, d.noNA$cond)
cohen.d(d.noNA$self_censor, d.noNA$cond)

cohen.d(d2_survey$warm_mean, d2_survey$cond)
cohen.d(d2_survey$pub_mean, d2_survey$cond)
