#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(ggplot2)
library(dplyr)
library(tidyr)

#move data folder to desktop
setwd("~/Desktop/Data")

d_withpoland = read.csv("field_idea_generation_w_poland.csv") #data with Poland site
d_all_gen = read.csv("field_generation_data_with_exclusions.csv") #all data, including exclusions
d_all_scored = read.csv("field_scored_data_with_exclusions.csv") #all scored data, including exclusions

table(d_all_gen$cond)
table(d_all_gen$keep)
table(d_all_scored$notes)
table(d_all_scored$cond, d_all_scored$keep)

#session size
session_size = d_all_gen %>% mutate(num = 1) %>%
  group_by(country, session) %>%
  summarise(session_size = sum(num))

mean(session_size$session_size)
median(session_size$session_size)
range(session_size$session_size)

#########################################################
# means by condition                                    #
#########################################################

d_withpoland %>% 
  group_by(cond) %>%
  summarise(mean = mean(idea_number, na.rm=T),
            sd = sd(idea_number, na.rm=T))

d_all_gen = d_all_gen %>% filter(keep!="3-person")
d_all_gen %>% 
  group_by(cond) %>%
  summarise(mean = mean(idea_number, na.rm=T),
            sd = sd(idea_number, na.rm=T))

d_all_scored %>% filter(keep!="3-person") %>%
  group_by(cond) %>%
  summarise(mean = mean(creative_count, na.rm=T),
            sd = sd(creative_count, na.rm=T))

#########################################################
# analyses                                             #
#########################################################

summary(glmer.nb(idea_number ~ cond + country + (1|session), data = d_withpoland))
summary(glmer.nb(idea_number ~ cond + country + (1|session), data = d_all_gen[d_all_gen$keep!="3-person",]))

#scored ideas
summary(lmer(diff ~ cond + country + (1|session), data=d_all_scored))
kruskal.test(diff ~ cond, data = d_all_scored)

#######################################################
# effect sizes                                        #
#######################################################

d_withpoland$cond = as.factor(d_withpoland$cond)
cohen.d(d_withpoland$idea_number, d_withpoland$cond)

d_all_gen$cond = as.factor(d_all_gen$cond)
cohen.d(d_all_gen$idea_number, d_all_gen$cond)

d_all_scored$cond = as.factor(d_all_scored$cond)
d.noNA = d_all_scored %>% filter(!is.na(diff))
cohen.d(d.noNA$diff, d.noNA$cond)
