setwd("~/Desktop/Data")

gaze = read.csv("eyegaze_data_by_participant.csv")
d = read.csv("eyegaze_data_by_group.csv")

#CLEAN DATA
graph = gaze %>% dplyr::select(cond, ends_with("_time"), -total_time) %>%
  gather(key, mean, ends_with("_time")) 

sem <- function(x) {sd(x, na.rm=TRUE) / sqrt(length(x))}
ci95 <- function(x) {sem(x) * 1.96}
graph2 = gaze %>% dplyr::select(cond, ends_with("_time"), -total_time) %>%
  gather(key, value, ends_with("_time")) %>%
  group_by(cond, key) %>%
  summarise(mean = mean(value), ci95=ci95(value))

graph$cond[graph$cond=="S"] = "Virtual"
graph$cond[graph$cond=="T"] = "In-Person"

graph$key[graph$key=="partner_time"] = "Partner"
graph$key[graph$key=="task_time"] = "Task"
graph$key[graph$key=="room_time"] = "Room"

graph2$cond[graph2$cond=="S"] = "Virtual"
graph2$cond[graph2$cond=="T"] = "In-Person"

graph2$key[graph2$key=="partner_time"] = "Partner"
graph2$key[graph2$key=="task_time"] = "Task"
graph2$key[graph2$key=="room_time"] = "Room"

graph$cond = as.factor(graph$cond)
graph$cond = droplevels(graph$cond)

graph$key = as.factor(graph$key)
graph$key = droplevels(graph$key)

graph2$cond = as.factor(graph2$cond)
graph2$cond = droplevels(graph2$cond)

graph2$key = as.factor(graph2$key)
graph2$key = droplevels(graph2$key)

graph2$key <- ordered(graph2$key, levels = c("Partner", "Task", "Room"))
graph$key <- ordered(graph$key, levels = c("Partner", "Task", "Room"))

ggplot(graph2, aes(x = key, y = mean, fill = cond, color = cond)) +
  geom_jitter(data=graph,
              aes(shape="1", fill = cond),
              alpha = 1,
              position = position_jitterdodge(jitter.width = 0.4, dodge.width = 0.8),
              size = .5,
              color="black") +
  geom_bar(data=graph2, position = position_dodge2(preserve = "single"), stat = "identity", alpha = .20, size=1) + 
  scale_fill_manual(values =  c("deepskyblue3", "navyblue")) +
  scale_color_manual(values =  c("deepskyblue3", "navyblue")) +
  ylab("Number of Seconds") +
  xlab("") +
  geom_errorbar(aes(ymin=mean-ci95, ymax=mean+ci95),
                width=.1,   
                size = .8,
                position=position_dodge(.9),
                color = "black") +
  theme_classic() +
  theme(axis.text.x = element_text(size=16), 
        axis.title.y = element_text(face="bold", size=16),
        axis.title.x = element_blank(),
        axis.text.y = element_text(size = 16),
        legend.text=element_text(size=14),
        legend.title = element_blank(), 
        plot.title = element_text( face = "bold", size = (15),hjust = 0.5))
