#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lmerTest)
library(effsize)
library(car)

#move data folder to desktop
setwd("~/Desktop/Data")

d = read.csv("forward_flow_data_long.csv")
d_avg = read.csv("forward_flow_data_avg.csv")

#########################################################
# means by condition                                    #
#########################################################

d_avg %>%
  group_by(cond) %>%
  summarise(mean = mean(score_z),
            sd = sd(score_z))

#########################################################
# Regressions                                           #
#########################################################

#interaction
summary(lmer(score_z ~ cond * idea_number + total_idea_number + study + (idea_number|Group.Number), data = d))

#simple effects
d = d %>% mutate(idea_number11 = idea_number - 11,
                 idea_number2 = idea_number - 2)

#note, we used the second idea in the sequence because the field study
#used the first idea as the seed word.

summary(lmer(score_z ~ cond * idea_number11 + total_idea_number + study + (idea_number|Group.Number), data = d))
summary(lmer(score_z ~ cond * idea_number2 + study + total_idea_number + (idea_number|Group.Number), data = d))

summary(lm(score_z ~ cond + study, data = d_avg))

#######################################################
# effect sizes                                        #
#######################################################

cohen.d(d_avg$score_z, d_avg$cond)

#######################################################
# test for normality                                  #
#######################################################

hist(d_avg$score_z)
shapiro.test(d_avg$score_z)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(score_z ~ cond, data = d_avg)

### non-parametric tests ###
kruskal.test(score_z ~ cond, data = d_avg)
