#################################################
# load libraries, read in data                  #
#################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d= read.csv("gender_composition_data.csv")

#################################################
# means                                         #
#################################################

d %>% 
  group_by(gender_comp) %>%
  summarise(mean = mean(creative_count, na.rm=T),
            sd = sd(creative_count, na.rm=T))

#################################################
# regressions                                   #
#################################################

d$gender_comp = as.factor(d$gender_comp)
summary(aov(creative_count ~ gender_comp, data = d))

summary(glm.nb(creative_count ~ female_num + study, data = d))
summary(glm.nb(creative_count ~ gender_comp + study, data = d))

summary(glm.nb(creative_count ~ female_num + cond + study, data = d))
summary(glm.nb(creative_count ~ gender_comp + cond + study, data = d))

#################################################
# exploratory                                   #
#################################################

d %>% 
  group_by(gender_comp, cond) %>%
  summarise(mean = mean(creative_count, na.rm=T),
            sd = sd(creative_count, na.rm=T))

contrasts(d$gender_comp)
contrasts(d$gender_comp) = cbind(c(1,0,0),c(0,1,0))

summary(glm.nb(creative_count ~ gender_comp * cond + study, data = d))
summary(glm.nb(creative_count ~ female_num * cond + study, data = d))