#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d1_survey = read.csv("study1_survey_by_participant.csv")
d2_survey = read.csv("study2_survey_by_participant.csv")
  
d1_all = read.csv("study1_survey_by_group.csv")
d2_all = read.csv("study2_survey_by_group.csv")

### combining data from study 1 and 2 ###

d1_illusion = d1_survey %>% dplyr::select(Group.Number, writer, study, enjoy, sat1, cond) %>%
  rename(sat = sat1)
d2_illusion = d2_survey %>% dplyr::select(Group.Number, writer, study, enjoy_t1, sat_t1, cond) %>%
  rename(enjoy = enjoy_t1,
         sat = sat_t1)
d_illusion = rbind(d1_illusion, d2_illusion)

d1_illusion_mean = d1_all %>% dplyr::select(Group.Number, study, enjoy, sat1, cond, creative_count) %>%
  rename(sat = sat1)
d2_illusion_mean = d2_all %>% dplyr::select(Group.Number, study, enjoy_t1, sat_t1, cond, creative_count) %>%
  rename(enjoy = enjoy_t1,
         sat = sat_t1)
d_illusion_mean = rbind(d1_illusion_mean, d2_illusion_mean)

#########################################################
# means by condition                                    #
#########################################################

d_illusion %>% 
  gather(key, value, enjoy, sat) %>%
  group_by(key,cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

#########################################################
# regressions                                           #
#########################################################

####### Does condition affect illusion of prod #########
  
summary(lmer(enjoy ~ cond + study + (1|Group.Number), data = d_illusion))
summary(lmer(sat ~ cond + study + (1|Group.Number), data = d_illusion))

### effect sizes ###
cohen.d(d_illusion$enjoy, d_illusion$cond)
cohen.d(d_illusion$sat, d_illusion$cond)

######### Does illusion of prod affect creativity #########
summary(glm.nb(creative_count ~ enjoy, data = d_illusion_mean))
summary(glm.nb(creative_count ~ sat, data = d_illusion_mean))

############ Controlling for illusion of prod #############
summary(glm.nb(creative_count ~ cond + enjoy, data = d_illusion_mean))
summary(glm.nb(creative_count ~ cond + sat, data = d_illusion_mean))

summary(glm.nb(creative_count ~ cond + sat + enjoy, data = d_illusion_mean))

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(d_illusion$enjoy ~ d_illusion$cond)
leveneTest(d_illusion$sat ~ d_illusion$cond)
