#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)

#move data folder to desktop
setwd("~/Desktop/Data")

d = read.csv("lingusitic_mimicry_data.csv")

#########################################################
# test for normality                                    #
 #########################################################

hist(d$LSM)
hist(d$cosine)

shapiro.test(d$LSM)
shapiro.test(d$cosine)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(cosine ~ cond, data = d)
leveneTest(LSM ~ cond, data = d)

#########################################################
# means by condition                                    #
#########################################################

d %>%
  gather(key, value, LSM, cosine) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

#########################################################
# Does condition affect linguistic mimicry               #
#########################################################

#LSM
summary(lm(LSM ~ cond + study, data = d))
summary(lm(LSM ~ cond + study + WC, data = d))


#cosine_all
summary(lm(cosine ~ cond + study, data = d))
summary(lm(cosine ~ cond + study + WC, data = d))

### non-parametric tests ###
kruskal.test(d$LSM ~ d$cond)
kruskal.test(d$cosine ~ d$cond)

######################################################
# Does linguistic mimicry affect creativity          #
######################################################

summary(glm.nb(creative_count ~ LSM + study, data = d))
summary(glm.nb(creative_count ~ cosine + study, data = d))

summary(glm.nb(creative_count ~ LSM + WC + study, data = d))
summary(glm.nb(creative_count ~ cosine + study, data = d))

cor.test(d$LSM, d$cosine)

######################################################
# controlling for linguistic mimicry                 #
######################################################

summary(glm.nb(creative_count ~ LSM + cond + study, data = d))
summary(glm.nb(creative_count ~ cosine + cond + study, data = d))

######################################################
# curvilinear? NO                                    #
######################################################
summary(glm.nb(creative_count ~ poly(LSM,2)  + cond, data = d))
summary(glm.nb(creative_count ~ poly(cosine,2)  + cond, data = d))

#######################################################
# effect sizes                                        #
#######################################################

cohen.d(d$LSM, d$cond)
cohen.d(d$cosine, d$cond)
