#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(effsize)
library(lmerTest)
library(car)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d_byp = read.csv("memory_data_by_participant.csv")
d = read.csv("memory_data_by_group.csv")

#########################################################
# means by condition                                    #
#########################################################

d_byp %>% dplyr::select(cond, contains("num_"), num_expected) %>%
  gather(key, value, contains("num_")) %>%
  group_by(cond, key) %>%
  summarise(mean = mean(value),
            sd = sd(value))

#########################################################
# regressions                                           #
#########################################################

summary(glmer(num_unexpected ~ cond + (1|Group.Number), family ="poisson",data=d_byp))
summary(glmer.nb(num_memory~ cond + (1|Group.Number), data=d_byp))

#########################################################
# mediation                                             #
#########################################################

#need to do a linear regression here because these are not integers

Model.M <-lm(num_unexpected ~ cond, data=d)
Model.Y <- glm.nb(creative_count ~ cond + num_unexpected, d)
med.model <- mediation::mediate(Model.M, Model.Y, treat= 'cond', mediator = 'num_unexpected', boot = T, sims = 10000) 
summary(med.model)

summary(Model.M)
summary(Model.Y)

summary(glm.nb(creative_count ~ cond, data = d))

#########################################################
# checks                                                #
#########################################################

summary(glmer.nb(num_unexpected ~ cond + (1|Group.Number), data=d_byp))
summary(lmer(num_unexpected ~ cond + (1|Group.Number), data=d_byp))

summary(glmer.nb(num_memory ~ cond + (1|Group.Number), data=d_byp))
summary(lmer(num_memory ~ cond + (1|Group.Number), data=d_byp))

summary(glmer.nb(num_expected ~ cond + (1|Group.Number), data=d_byp))
summary(lmer(num_expected ~ cond + (1|Group.Number), data = d_byp))

########################################################
# effect sizes                                         #
########################################################

cohen.d(d_byp$num_memory, d_byp$cond)
cohen.d(d_byp$num_unexpected, d_byp$cond)
cohen.d(d_byp$num_expected, d_byp$cond)

#######################################################
# testing assumptions                                 #
#######################################################

#poisson
possion1 = glm(num_memory ~ cond, family="poisson",data = d_byp)
possion2 = glm(num_unexpected ~ cond, family="poisson",data = d_byp)

#negative binomial
negbin1 = glm.nb(num_memory ~ cond, data = d_byp)
negbin2 = glm.nb(num_unexpected ~ cond, data = d_byp)

library(AER)
dispersiontest(possion1,trafo=1)
dispersiontest(possion2,trafo=1)

AIC(possion1, negbin1)
AIC(possion2, negbin2)

library(pscl)
vuong(possion1, negbin1, digits = 4)
vuong(possion2, negbin2, digits = 4)

