#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(broom)
library(broom.mixed)
library(MASS)
library(purrr)

#move data folder to desktop
setwd("~/Desktop/Data")

d = read.csv("muted_video_codes.csv")

#########################################################
# means by condition                                    #
#########################################################

rs = lmer(d[,5] ~ cond + (1|Group.Number) + (1|video) + (1|coder_id), data=d)
results = broom::tidy(rs)
results$key = rep(names(d[2]))

for(i in 5:17){
  rs = lmer(d[,i] ~ cond + (1|Group.Number) + (1|video) + (1|coder_id), data =d)
  stats = broom::tidy(rs)
  stats$key = rep(names(d[i]))
  results = rbind(results, stats)
}

results = results %>% filter(term=="condvideo") %>%
  dplyr::select(-group, -effect, -term)

table_mean = d %>% 
  gather(key, value, -video, -coder_id, -cond, -Group.Number) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm =T)) %>%
  mutate(mean = round(mean, 2)) %>%
  spread(cond, mean) %>%
  rename(virtual_mean = video,
         inperson_mean = f2f)

table_sd = d %>% 
  gather(key, value, -video, -coder_id, -cond, -Group.Number) %>%
  group_by(key, cond) %>%
  summarise(sd = sd(value, na.rm =T)) %>%
  mutate(sd = round(sd, 2)) %>%
  spread(cond, sd) %>%
  rename(virtual_sd = video,
         inperson_sd = f2f)

table = merge(table_mean, table_sd, by = "key")

summary_muted = merge(table, results, by="key")

summary_muted$estimate = round(summary_muted$estimate,2)
summary_muted$std.error = round(summary_muted$std.error,2)
summary_muted$statistic = round(summary_muted$statistic,2)
summary_muted$p.value = round(summary_muted$p.value,3)

#######################################################
# predicting creativity                               #
#######################################################

d.gen = read.csv("study2_data.csv")
d.gen = d.gen %>% dplyr::select(Group.Number, creative_count)

muted_mean = d %>% dplyr::select(-coder_id) %>%
  group_by(Group.Number, cond, video) %>%
  summarise_each(funs(mean(., na.rm = TRUE))) %>%
  dplyr::select(-video) %>%
  group_by(Group.Number, cond) %>%
  summarise_each(funs(mean(., na.rm = TRUE)))
    
d.gen = merge(d.gen, muted_mean, by = c("Group.Number"))

coefficient_predict_creative = d.gen %>% 
  gather(key, value, -Group.Number, -cond, -creative_count) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ glm.nb(creative_count ~ value, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  filter(term=="value") %>%
  mutate(p.value = round(p.value,3))

#######################################################
# Results                                             #
#######################################################

#write.csv(summary_muted, "table_cond_predict_muted_videos.csv")
#write.csv(coefficient_predict_creative, "muted_videos_predict_generation.csv")

l_test = d %>% 
  gather(key, value, -Group.Number, - video, -id, -cond) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ leveneTest(value ~ cond, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  mutate(p.value = round(p.value,3)) %>%
  dplyr::select(-data, -fit)

library(nlme)
lme.raw <- lme(fixed = facial_expression ~ cond, random =~1|video, data=d)
anova(lme.raw)
