#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d1_survey = read.csv("study1_survey_by_participant.csv")
d1_all = read.csv("study1_survey_by_group.csv")

#########################################################
# means by condition                                    #
#########################################################

d1_survey %>% group_by(cond) %>%
  summarise(mean = mean(block1, na.rm=T),
            sd = sd(block1, na.rm=T))

#########################################################
# Regressions                                           #
#########################################################

######### Does condition affect production blocking ###########
summary(lmer(block1 ~ cond + (1|Group.Number), data = d1_survey))

######### Does production blocking affect creativity #########
summary(glm.nb(creative_count ~ block1, data = d1_all))

######### Controlling for production blocking #########
summary(glm.nb(creative_count ~ block1 + cond, data = d1_all))

######### Effect Size #########
d.noNA = d1_survey %>% filter(!is.na(block1))
cohen.d(d.noNA$block1, d.noNA$cond)

#########################################################
# test for normality                                    #
#########################################################

hist(d1_survey$block1)

shapiro.test(d1_survey$block1)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(block1 ~ cond, data = d1_survey)

### non-parametric tests ###
kruskal.test(block1 ~ cond, data = d1_all)
