#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d2_survey = read.csv("study2_survey_by_participant.csv")
d2_all = read.csv("study2_survey_by_group.csv")

#########################################################
# means by condition                                    #
#########################################################

d2_survey %>% group_by(cond) %>%
  summarise(mean = mean(arousal),
            sd = sd(arousal))

#########################################################
# Regressions                                           #
#########################################################

######### Does condition affect arousal ###########
summary(lmer(arousal ~ cond + (1|Group.Number), data = d2_survey))

######### Does arousal affect creativity #########
summary(glm.nb(creative_count ~ arousal, data = d2_all))

######### Controlling for arousal #########
summary(glm.nb(creative_count ~ cond + arousal, data = d2_all))

######### Effect Size #########
cohen.d(d2_survey$arousal, d2_survey$cond)

#########################################################
# test for normality                                    #
#########################################################

hist(d2_survey$arousal)

shapiro.test(d2_survey$arousal)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(arousal ~ cond, data = d2_survey)

### non-parametric tests ###
kruskal.test(arousal ~ cond, data = d2_all)
