#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d1_survey = read.csv("study1_survey_by_participant.csv")
d1_gen = read.csv("study1_data.csv")
d1_all = read.csv("study1_survey_by_group.csv")

#########################################################
# means by condition                                    #
#########################################################

d1_survey %>% dplyr::select(Group.Number, pshare, share, cond) %>%
  gather(key, value, pshare, share) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

#########################################################
# regressions                                           #
#########################################################

####### Does condition affect social loafing #########
summary(lmer(pshare ~ cond + (1|Group.Number), data = d1_survey))
summary(lmer(share ~ cond + (1|Group.Number), data = d1_survey))

######### Does social loafing affect creativity #########
d_loaf = d1_survey %>% dplyr::select(Group.Number, pshare, share) %>%
  group_by(Group.Number) %>%
  summarise_all(mean)

d_loaf = merge(d1_gen, d_loaf, by = "Group.Number")

summary(glm.nb(creative_count ~ pshare, data = d_loaf))
summary(glm.nb(creative_count ~ share, data = d_loaf))

############ Controlling for social loafing #############
summary(glm.nb(creative_count ~ pshare + cond, data = d_loaf))
summary(glm.nb(creative_count ~ share + cond, data = d_loaf))
summary(glm.nb(creative_count ~ share + pshare + cond, data = d_loaf))

#########################################################
# test for normality                                    #
#########################################################

hist(d_loaf$share)
hist(d_loaf$pshare)

shapiro.test(d_loaf$share)
shapiro.test(d_loaf$pshare)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(share ~ cond, data = d_loaf)
leveneTest(pshare ~ cond, data = d_loaf)

### non-parametric tests ###
kruskal.test(share ~ cond, data = d_loaf)
kruskal.test(pshare ~ cond, data = d_loaf)

#########################################################
# Effect Sizes                                          #
#########################################################

d1_survey$cond = as.factor(d1_survey$cond)
d.noNA = d1_survey %>% filter(!is.na(pshare))

cohen.d(d.noNA$pshare, d.noNA$cond)
cohen.d(d.noNA$share, d.noNA$cond)
