#################################################
# load libraries, read in data                  #
#################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

sim = read.csv("social_sensitivity_data.csv")
d = read.csv("social_sensitivity_by_group_data.csv")

#################################################
# means                                         #
#################################################

sim %>% 
  group_by(cond) %>%
  summarise(mean = mean(cosine_sim, na.rm=T),
            sd = sd(cosine_sim, na.rm=T))

summary(lmer(cosine_sim ~ cond + (1|Group.Number), data = sim))

summary(glm.nb(creative_count ~ cosine_sim, data = d))

summary(glm.nb(creative_count ~ cosine_sim + cond, data = d))

#########################################################
# Effect Sizes                                          #
#########################################################

sim$cond = as.factor(sim$cond)
cohen.d(sim$cosine_sim, sim$cond)

#########################################################
# test for normality                                    #
#########################################################

hist(sim$cosine_sim)

shapiro.test(sim$cosine_sim)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(cosine_sim ~ cond, data = sim)

### non-parametric tests ###
kruskal.test(cosine_sim ~ cond, data = d)


