#################################################
# load libraries, read in data                  #
#################################################
rm(list=ls())
library(dplyr)
library(psych)
library(lmerTest)
library(mediation)
library(tidyr)

#move data folder to desktop
setwd("~/Desktop/Data")

gaze_full = read.csv("indivdual_gaze_wexclusions.csv")
d_full = read.csv("gaze_mean_wexclusions.csv")

########################################
#effect of condition on gaze           #
########################################

gaze_full %>% gather(key, value, contains("time"), - total_time, -total_time_check) %>%
  group_by(key,cond) %>%
  summarise(mean = mean(value),
            sd = sd(value))

summary(lmer(task_time ~ cond + (1|Group.Number), data= gaze_full))
summary(lmer(partner_time ~ cond + (1|Group.Number), data= gaze_full))
summary(lmer(room_time ~ cond + (1|Group.Number), data= gaze_full))

gaze_full %>% gather(key, value, contains("time")) %>%
  group_by(key,cond) %>%
  summarise(mean = mean(value),
            sd = sd(value))


Model.M <- lm(room_time ~ cond, data=d_full)
Model.Y <- glm.nb(creative_count ~ cond + room_time, d_full)
med.model <- mediation::mediate(Model.M, Model.Y, treat= 'cond', mediator = 'room_time', boot = T, sims = 5000)  
summary(med.model) 

summary(Model.Y)
summary(Model.M)

#######################################################
# Effect Sizes                                        #
#######################################################

gaze_full$cond = as.factor(gaze_full$cond)

cohen.d(gaze_full$task_time, gaze_full$cond)
cohen.d(gaze_full$partner_time, gaze_full$cond)
cohen.d(gaze_full$room_time, gaze_full$cond)



