#################################################
# load libraries, read in data                  #
#################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(broom.mixed)
library(broom)

#move data folder to desktop
setwd("~/Desktop/Data")

survey_byp = read.csv("study2_survey_by_participant.csv")
survey = read.csv("study2_survey_by_group.csv")

#######################################################
# Demographic Information                             #
#######################################################

summary(survey_byp$sex)
table(survey_byp$sex)
mean(survey_byp$age, na.rm=T)
sd(survey_byp$age, na.rm=T)

#######################################################
# differences by condition                            #
#######################################################

survey2 = survey_byp %>%
  select(-writer, -sex, -native, -race, -age, -major, -study) %>%
  gather(key, value, -Group.Number, -cond) %>%
  filter(!is.na(value))

survey_byp = survey_byp %>% select(-writer, -sex, -native, -race, -age, -major, -study)

rs = lmer(survey_byp[,3] ~ cond + (1|Group.Number), data=survey_byp)
results = broom::tidy(rs)
results$key = rep(names(survey_byp[2]))

for(i in 3:32){
  rs = lmer(survey_byp[,i] ~ cond + (1|Group.Number), data =survey_byp)
  stats = broom::tidy(rs)
  stats$key = rep(names(survey_byp[i]))
  results = rbind(results, stats)
}

results = results %>% filter(term=="condvideo") %>%
  select(-group, -effect, -term)

survey2$cond <- factor(survey2$cond, levels = c("f2f", "video"))
table_mean = survey2 %>% select(-Group.Number) %>%
  group_by(key, cond) %>%
  summarise_each(funs(mean(., na.rm = TRUE))) %>%
  mutate(value = round(value, 2)) %>%
  spread(cond, value) %>%
  rename(f2f_mean = f2f,
         video_mean = video)

table_sd = survey2 %>% select(-Group.Number) %>%
  group_by(key, cond) %>%
  summarise_each(funs(sd(., na.rm = TRUE))) %>%
  mutate(value = round(value, 2)) %>%
  spread(cond, value) %>%
  rename(f2f_SD = f2f,
         video_SD = video)

table = merge(table_sd, table_mean, by="key")

summary_survey = merge(table, results, by="key")
