#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d1_byp = read.csv("study1_survey_by_participant.csv")
d2_byp = read.csv("study2_survey_by_participant.csv")

d1 = read.csv("study1_survey_by_group.csv")
d2 = read.csv("study2_survey_by_group.csv")

#########################################################
# means by condition                                    #
#########################################################

### survey items in study 1 ###

d1_byp %>%
  gather(key, value, sim, like, sync_mean) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

### trust game in study 2 ###

d2_byp %>%
  group_by(cond) %>%
  summarise(mean = mean(money_entrust, na.rm=T),
            sd = sd(money_entrust, na.rm=T))

#########################################################
# test for normality                                    #
#########################################################

hist(d1_byp$sim)
hist(d1_byp$like)
hist(d1_byp$sync_mean)
hist(d2_byp$money_entrusted)

shapiro.test(d1_byp$sync_mean)
shapiro.test(d1_byp$like)
shapiro.test(d1_byp$sim)
shapiro.test(d2_byp$money_entrusted)

#########################################################
# regressions                                           #
#########################################################

### survey items in study 1 ###

summary(lmer(like ~ cond + (1|Group.Number), data=d1_byp))
summary(glm.nb(creative_count ~ like, data = d1))
summary(glm.nb(creative_count ~ cond + like, data = d1))

summary(lmer(sim ~ cond + (1|Group.Number), data=d1_byp))
summary(glm.nb(creative_count ~ sim, data = d1))
summary(glm.nb(creative_count ~ cond + sim,data = d1))

summary(lmer(sync_mean ~ cond + (1|Group.Number), data=d1_byp))
summary(glm.nb(creative_count ~ sync_mean, data = d1))
summary(glm.nb(creative_count ~ cond + sync_mean, data = d1))

### non-parametric tests ###

kruskal.test(d1$sync_mean ~ d1$cond)
kruskal.test(d1$like ~ d1$cond)
kruskal.test(d1$sim ~ d1$cond)

### controlling for all three ###

summary(glm.nb(creative_count ~ cond + sync_mean + like + sim, data = d1))

### trust game in study 2 ###

summary(lmer(money_entrust ~ cond + (1|Group.Number), data=d2_byp))
summary(glm.nb(creative_count ~ money_entrust, data = d2))
summary(glm.nb(creative_count ~ cond + money_entrust, data = d2))

kruskal.test(d2$money_entrust ~ d2$cond)

#######################################################
# effect sizes                                        #
#######################################################

d1.noNA = d1_byp %>% filter(!is.na(sim))%>%
  mutate(cond = as.factor(cond))
cohen.d(d1.noNA$sim, d1.noNA$cond)
cohen.d(d1.noNA$like, d1.noNA$cond)
cohen.d(d1.noNA$sync_mean, d1.noNA$cond)

cohen.d(d2_byp$money_entrust, d2_byp$cond)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(money_entrust ~ cond, data = d2_byp)
leveneTest(sim ~ cond, data = d1_byp)
leveneTest(like ~ cond, data = d1_byp)
leveneTest(sync_mean ~ cond, data = d1_byp)