#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(effsize)
library(car)

#move data folder to desktop
setwd("~/Desktop/Data")

d = read.csv("virtual_study_data.csv")
d$Group.Size = as.factor(d$Group.Size)

#########################################################
# test for normality                                    #
#########################################################

hist(d$ideas_per_person)
hist(d$creative_per_person)

shapiro.test(d$ideas_per_person)
shapiro.test(d$creative_per_person)
shapiro.test(d$avg_creative)
shapiro.test(d$var_creative)
shapiro.test(d$diff)
shapiro.test(d$p_select_creative)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(ideas_per_person ~ Group.Size, data = d)
leveneTest(creative_per_person ~ Group.Size, data = d)
leveneTest(avg_creative ~ Group.Size, data = d)
leveneTest(var_creative ~ Group.Size, data = d)
leveneTest(diff ~ Group.Size, data = d)
leveneTest(p_select_creative ~ Group.Size, data = d)

#########################################################
# means by condition                                    #
#########################################################

table(d$Group.Size)

table = d %>% dplyr::select(-creative_count, -idea_number) %>%
  gather(key, value, -Group.Number, -Group.Size) %>%
  group_by(key, Group.Size) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

#########################################################
# regressions                                           #
#########################################################

### main analysis: idea generation ###

### non-parametric tests ###
kruskal.test(ideas_per_person ~ Group.Size, data = d)
kruskal.test(creative_per_person ~ Group.Size, data = d)

### main analysis: idea selection ###

summary(lm(diff ~ Group.Size, data=d))
kruskal.test(diff ~ Group.Size, data = d)
summary(lm(p_select_creative ~ Group.Size, data=d))
summary(lm(p_select_creative ~ Group.Size + top_creative, data=d))
summary(lm(top_creative ~ Group.Size, data=d))

#######################################################
# controls & checks                                   #
#######################################################

#controlling for idea number and variance
summary(lm(diff ~ Group.Size + idea_number, data=d))
summary(lm(p_select_creative ~ Group.Size + top_creative + idea_number, data=d))

#checking other measures of idea quality
summary(lm(avg_creative ~ Group.Size, data=d))
summary(lm(avg_top_creative ~ Group.Size, data=d))
summary(lm(var_creative ~ Group.Size, data=d))

#######################################################
# effect sizes                                        #
#######################################################

cohen.d(d$ideas_per_person, d$Group.Size)
cohen.d(d$creative_per_person, d$Group.Size)
cohen.d(d$avg_creative, d$Group.Size)
cohen.d(d$avg_top_creative, d$Group.Size)
cohen.d(d$var_creative, d$Group.Size)
cohen.d(d$top_creative, d$Group.Size)
cohen.d(d$p_select_creative, d$Group.Size)
cohen.d(d$diff, d$Group.Size)
cohen.d(d$p_select_creative, d$Group.Size)

#######################################################
# nominal groups                                      #
#######################################################

table(d_nom$Group.Size)

d_nom = read.csv("study3_nominal_groups_data.csv")

table = d_nom %>%
  gather(key, value, -Group.Number, -Group.Size, -Group.Number_old) %>%
  group_by(key, Group.Size) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

### main analysis: idea generation ###

summary(glm.nb(idea_number ~ Group.Size, data=d_nom))

summary(glm.nb(creative_count ~ Group.Size, data=d_nom))

cohen.d(d_nom$idea_number, d_nom$Group.Size)
cohen.d(d_nom$creative_count, d_nom$Group.Size)

