#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(broom.mixed)
library(broom)
library(MASS)
library(purrr)
library(car)

#move data folder to desktop
setwd("~/Desktop/Data")

survey_byp_full = read.csv("virtual_study_survey_byp.csv")

survey_byp = survey_byp_full %>% dplyr::select(-major, -Group.Size, -session, -cond)

survey_mean = survey_byp %>%
  group_by(Group.Number, school) %>%
  summarise_each(funs(mean(., na.rm = TRUE)))

d.gen = read.csv("virtual_study_data.csv")
d.gen = d.gen %>% dplyr::select(Group.Number, Group.Size, creative_per_person, ideas_per_person, diff)
d = merge(d.gen, survey_mean, by = c("Group.Number"))

d$Group.Size = as.factor(d$Group.Size)

#########################################################
# descriptives                                          #
#########################################################

range(survey_byp$screen_size)
mean(d$screen_size)
range(d$screen_size)

aggregate(survey_byp_full$room_num, list(survey_byp_full$cond), mean)
aggregate(survey_byp_full$room_num, list(survey_byp_full$cond), sd)

#######################################################
# random assignment check                             #
#######################################################

summary(lm(screen_size ~ Group.Size, data = d))
aggregate(d$screen_size, list(d$Group.Size), mean)
aggregate(d$screen_size, list(d$Group.Size), sd)

#########################################################
# regressions                                           #
#########################################################

### main analysis: idea generation ###
summary(lm(ideas_per_person ~ Group.Size + screen_size, data=d))
summary(lm(creative_per_person ~ screen_size + Group.Size, data=d))

kruskal.test(ideas_per_person ~ screen_size, data = d)
kruskal.test(creative_per_person ~ screen_size, data = d)

summary(lmer(room_num ~ cond + (1|Group.Number), data = survey_byp_full))

#######################################################
# controls & checks                                   #
#######################################################

d$income[d$income ==7] = d$income[d$income ==7] = NA # 7 = prefer not to answer

#pre-reg covariates
summary(lm(creative_per_person ~ screen_size + Group.Size + income  + comp_time, data=d))
summary(lm(ideas_per_person ~ screen_size + Group.Size + income  + comp_time, data=d))

#all covariates
summary(lm(creative_per_person ~ screen_size + Group.Size + income  + comp_time + comfort + age + sex + native, data=d))
summary(lm(ideas_per_person ~ screen_size + Group.Size + income  + comp_time + comfort + age + sex + native, data=d))

#moderation check
summary(lm(creative_per_person ~ screen_size * Group.Size, data=d))
summary(lm(ideas_per_person ~ screen_size * Group.Size, data=d))
